@@ -161,6 +161,21 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         """
         return self._transport
 
+    @staticmethod
+    def alert_policy_path(project: str, alert_policy: str,) -> str:
+        """Returns a fully-qualified alert_policy string."""
+        return "projects/{project}/alertPolicies/{alert_policy}".format(
+            project=project, alert_policy=alert_policy,
+        )
+
+    @staticmethod
+    def parse_alert_policy_path(path: str) -> Dict[str, str]:
+        """Parses a alert_policy path into its component segments."""
+        m = re.match(
+            r"^projects/(?P<project>.+?)/alertPolicies/(?P<alert_policy>.+?)$", path
+        )
+        return m.groupdict() if m else {}
+
     @staticmethod
     def dashboard_path(project: str, dashboard: str,) -> str:
         """Returns a fully-qualified dashboard string."""
@@ -359,11 +374,10 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
     ) -> dashboard.Dashboard:
         r"""Creates a new custom dashboard. For examples on how you can use
         this API to create dashboards, see `Managing dashboards by
-        API <https://cloud.google.com/monitoring/dashboards/api-dashboard>`__.
-        This method requires the ``monitoring.dashboards.create``
-        permission on the specified project. For more information about
-        permissions, see `Cloud Identity and Access
-        Management <https://cloud.google.com/iam>`__.
+        API </monitoring/dashboards/api-dashboard>`__. This method
+        requires the ``monitoring.dashboards.create`` permission on the
+        specified project. For more information about permissions, see
+        `Cloud Identity and Access Management </iam>`__.
 
         Args:
             request (google.cloud.monitoring_dashboard_v1.types.CreateDashboardRequest):
