@@ -81,14 +81,14 @@ class DashboardsServiceGrpcAsyncIOTransport(DashboardsServiceTransport):
             aio.Channel: A gRPC AsyncIO channel object.
         """
 
-        self_signed_jwt_kwargs = cls._get_self_signed_jwt_kwargs(host, scopes)
-
         return grpc_helpers_async.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
             quota_project_id=quota_project_id,
-            **self_signed_jwt_kwargs,
+            default_scopes=cls.AUTH_SCOPES,
+            scopes=scopes,
+            default_host=cls.DEFAULT_HOST,
             **kwargs,
         )
 
@@ -106,6 +106,7 @@ class DashboardsServiceGrpcAsyncIOTransport(DashboardsServiceTransport):
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
         quota_project_id=None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
+        always_use_jwt_access: Optional[bool] = False,
     ) -> None:
         """Instantiate the transport.
 
@@ -147,6 +148,8 @@ class DashboardsServiceGrpcAsyncIOTransport(DashboardsServiceTransport):
                 API requests. If ``None``, then default info will be used.
                 Generally, you only need to set this if you're developing
                 your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
 
         Raises:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
@@ -198,6 +201,7 @@ class DashboardsServiceGrpcAsyncIOTransport(DashboardsServiceTransport):
             scopes=scopes,
             quota_project_id=quota_project_id,
             client_info=client_info,
+            always_use_jwt_access=always_use_jwt_access,
         )
 
         if not self._grpc_channel:
@@ -237,11 +241,10 @@ class DashboardsServiceGrpcAsyncIOTransport(DashboardsServiceTransport):
 
         Creates a new custom dashboard. For examples on how you can use
         this API to create dashboards, see `Managing dashboards by
-        API <https://cloud.google.com/monitoring/dashboards/api-dashboard>`__.
-        This method requires the ``monitoring.dashboards.create``
-        permission on the specified project. For more information about
-        permissions, see `Cloud Identity and Access
-        Management <https://cloud.google.com/iam>`__.
+        API </monitoring/dashboards/api-dashboard>`__. This method
+        requires the ``monitoring.dashboards.create`` permission on the
+        specified project. For more information about permissions, see
+        `Cloud Identity and Access Management </iam>`__.
 
         Returns:
             Callable[[~.CreateDashboardRequest],
