@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,10 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.monitoring_dashboard_v1.types import layouts
 
 
@@ -45,32 +42,34 @@ class Dashboard(proto.Message):
             that their change will be applied to the same version of the
             Dashboard configuration. The field should not be passed
             during dashboard creation.
-        grid_layout (~.layouts.GridLayout):
+        grid_layout (google.cloud.monitoring_dashboard_v1.types.GridLayout):
             Content is arranged with a basic layout that
             re-flows a simple list of informational elements
             like widgets or tiles.
-        row_layout (~.layouts.RowLayout):
+        mosaic_layout (google.cloud.monitoring_dashboard_v1.types.MosaicLayout):
+            The content is arranged as a grid of tiles,
+            with each content widget occupying one or more
+            grid blocks.
+        row_layout (google.cloud.monitoring_dashboard_v1.types.RowLayout):
             The content is divided into equally spaced
             rows and the widgets are arranged horizontally.
-        column_layout (~.layouts.ColumnLayout):
+        column_layout (google.cloud.monitoring_dashboard_v1.types.ColumnLayout):
             The content is divided into equally spaced
             columns and the widgets are arranged vertically.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    display_name = proto.Field(proto.STRING, number=2)
-
-    etag = proto.Field(proto.STRING, number=4)
-
+    name = proto.Field(proto.STRING, number=1,)
+    display_name = proto.Field(proto.STRING, number=2,)
+    etag = proto.Field(proto.STRING, number=4,)
     grid_layout = proto.Field(
         proto.MESSAGE, number=5, oneof="layout", message=layouts.GridLayout,
     )
-
+    mosaic_layout = proto.Field(
+        proto.MESSAGE, number=6, oneof="layout", message=layouts.MosaicLayout,
+    )
     row_layout = proto.Field(
         proto.MESSAGE, number=8, oneof="layout", message=layouts.RowLayout,
     )
-
     column_layout = proto.Field(
         proto.MESSAGE, number=9, oneof="layout", message=layouts.ColumnLayout,
     )
