@@ -39,12 +39,10 @@ from google.cloud.monitoring_dashboard_v1.services.dashboards_service import (
 )
 from google.cloud.monitoring_dashboard_v1.services.dashboards_service import pagers
 from google.cloud.monitoring_dashboard_v1.services.dashboards_service import transports
-from google.cloud.monitoring_dashboard_v1.services.dashboards_service.transports.base import (
-    _API_CORE_VERSION,
-)
 from google.cloud.monitoring_dashboard_v1.services.dashboards_service.transports.base import (
     _GOOGLE_AUTH_VERSION,
 )
+from google.cloud.monitoring_dashboard_v1.types import alertchart
 from google.cloud.monitoring_dashboard_v1.types import common
 from google.cloud.monitoring_dashboard_v1.types import dashboard
 from google.cloud.monitoring_dashboard_v1.types import dashboards_service
@@ -59,8 +57,9 @@ from google.protobuf import duration_pb2  # type: ignore
 import google.auth
 
 
-# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
-# - Delete all the api-core and auth "less than" test cases
+# TODO(busunkim): Once google-auth >= 1.25.0 is required transitively
+# through google-api-core:
+# - Delete the auth "less than" test cases
 # - Delete these pytest markers (Make the "greater than or equal to" tests the default).
 requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
     packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
@@ -71,16 +70,6 @@ requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
     reason="This test requires google-auth >= 1.25.0",
 )
 
-requires_api_core_lt_1_26_0 = pytest.mark.skipif(
-    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
-    reason="This test requires google-api-core < 1.26.0",
-)
-
-requires_api_core_gte_1_26_0 = pytest.mark.skipif(
-    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
-    reason="This test requires google-api-core >= 1.26.0",
-)
-
 
 def client_cert_source_callback():
     return b"cert bytes", b"key bytes"
@@ -144,6 +133,36 @@ def test_dashboards_service_client_from_service_account_info(client_class):
         assert client.transport._host == "monitoring.googleapis.com:443"
 
 
+@pytest.mark.parametrize(
+    "client_class", [DashboardsServiceClient, DashboardsServiceAsyncClient,]
+)
+def test_dashboards_service_client_service_account_always_use_jwt(client_class):
+    with mock.patch.object(
+        service_account.Credentials, "with_always_use_jwt_access", create=True
+    ) as use_jwt:
+        creds = service_account.Credentials(None, None, None)
+        client = client_class(credentials=creds)
+        use_jwt.assert_not_called()
+
+
+@pytest.mark.parametrize(
+    "transport_class,transport_name",
+    [
+        (transports.DashboardsServiceGrpcTransport, "grpc"),
+        (transports.DashboardsServiceGrpcAsyncIOTransport, "grpc_asyncio"),
+    ],
+)
+def test_dashboards_service_client_service_account_always_use_jwt_true(
+    transport_class, transport_name
+):
+    with mock.patch.object(
+        service_account.Credentials, "with_always_use_jwt_access", create=True
+    ) as use_jwt:
+        creds = service_account.Credentials(None, None, None)
+        transport = transport_class(credentials=creds, always_use_jwt_access=True)
+        use_jwt.assert_called_once_with(True)
+
+
 @pytest.mark.parametrize(
     "client_class", [DashboardsServiceClient, DashboardsServiceAsyncClient,]
 )
@@ -1611,7 +1630,6 @@ def test_dashboards_service_transport_auth_adc_old_google_auth(transport_class):
         (transports.DashboardsServiceGrpcAsyncIOTransport, grpc_helpers_async),
     ],
 )
-@requires_api_core_gte_1_26_0
 def test_dashboards_service_transport_create_channel(transport_class, grpc_helpers):
     # If credentials and host are not provided, the transport class should use
     # ADC credentials.
@@ -1645,84 +1663,6 @@ def test_dashboards_service_transport_create_channel(transport_class, grpc_helpe
         )
 
 
-@pytest.mark.parametrize(
-    "transport_class,grpc_helpers",
-    [
-        (transports.DashboardsServiceGrpcTransport, grpc_helpers),
-        (transports.DashboardsServiceGrpcAsyncIOTransport, grpc_helpers_async),
-    ],
-)
-@requires_api_core_lt_1_26_0
-def test_dashboards_service_transport_create_channel_old_api_core(
-    transport_class, grpc_helpers
-):
-    # If credentials and host are not provided, the transport class should use
-    # ADC credentials.
-    with mock.patch.object(
-        google.auth, "default", autospec=True
-    ) as adc, mock.patch.object(
-        grpc_helpers, "create_channel", autospec=True
-    ) as create_channel:
-        creds = ga_credentials.AnonymousCredentials()
-        adc.return_value = (creds, None)
-        transport_class(quota_project_id="octopus")
-
-        create_channel.assert_called_with(
-            "monitoring.googleapis.com:443",
-            credentials=creds,
-            credentials_file=None,
-            quota_project_id="octopus",
-            scopes=(
-                "https://www.googleapis.com/auth/cloud-platform",
-                "https://www.googleapis.com/auth/monitoring",
-                "https://www.googleapis.com/auth/monitoring.read",
-                "https://www.googleapis.com/auth/monitoring.write",
-            ),
-            ssl_credentials=None,
-            options=[
-                ("grpc.max_send_message_length", -1),
-                ("grpc.max_receive_message_length", -1),
-            ],
-        )
-
-
-@pytest.mark.parametrize(
-    "transport_class,grpc_helpers",
-    [
-        (transports.DashboardsServiceGrpcTransport, grpc_helpers),
-        (transports.DashboardsServiceGrpcAsyncIOTransport, grpc_helpers_async),
-    ],
-)
-@requires_api_core_lt_1_26_0
-def test_dashboards_service_transport_create_channel_user_scopes(
-    transport_class, grpc_helpers
-):
-    # If credentials and host are not provided, the transport class should use
-    # ADC credentials.
-    with mock.patch.object(
-        google.auth, "default", autospec=True
-    ) as adc, mock.patch.object(
-        grpc_helpers, "create_channel", autospec=True
-    ) as create_channel:
-        creds = ga_credentials.AnonymousCredentials()
-        adc.return_value = (creds, None)
-
-        transport_class(quota_project_id="octopus", scopes=["1", "2"])
-
-        create_channel.assert_called_with(
-            "monitoring.googleapis.com:443",
-            credentials=creds,
-            credentials_file=None,
-            quota_project_id="octopus",
-            scopes=["1", "2"],
-            ssl_credentials=None,
-            options=[
-                ("grpc.max_send_message_length", -1),
-                ("grpc.max_receive_message_length", -1),
-            ],
-        )
-
-
 @pytest.mark.parametrize(
     "transport_class",
     [
@@ -1745,12 +1685,7 @@ def test_dashboards_service_grpc_transport_client_cert_source_for_mtls(transport
             "squid.clam.whelk:443",
             credentials=cred,
             credentials_file=None,
-            scopes=(
-                "https://www.googleapis.com/auth/cloud-platform",
-                "https://www.googleapis.com/auth/monitoring",
-                "https://www.googleapis.com/auth/monitoring.read",
-                "https://www.googleapis.com/auth/monitoring.write",
-            ),
+            scopes=None,
             ssl_credentials=mock_ssl_channel_creds,
             quota_project_id=None,
             options=[
@@ -1859,12 +1794,7 @@ def test_dashboards_service_transport_channel_mtls_with_client_cert_source(
                 "mtls.squid.clam.whelk:443",
                 credentials=cred,
                 credentials_file=None,
-                scopes=(
-                    "https://www.googleapis.com/auth/cloud-platform",
-                    "https://www.googleapis.com/auth/monitoring",
-                    "https://www.googleapis.com/auth/monitoring.read",
-                    "https://www.googleapis.com/auth/monitoring.write",
-                ),
+                scopes=None,
                 ssl_credentials=mock_ssl_cred,
                 quota_project_id=None,
                 options=[
@@ -1911,12 +1841,7 @@ def test_dashboards_service_transport_channel_mtls_with_adc(transport_class):
                 "mtls.squid.clam.whelk:443",
                 credentials=mock_cred,
                 credentials_file=None,
-                scopes=(
-                    "https://www.googleapis.com/auth/cloud-platform",
-                    "https://www.googleapis.com/auth/monitoring",
-                    "https://www.googleapis.com/auth/monitoring.read",
-                    "https://www.googleapis.com/auth/monitoring.write",
-                ),
+                scopes=None,
                 ssl_credentials=mock_ssl_cred,
                 quota_project_id=None,
                 options=[
@@ -1927,9 +1852,31 @@ def test_dashboards_service_transport_channel_mtls_with_adc(transport_class):
             assert transport.grpc_channel == mock_grpc_channel
 
 
-def test_dashboard_path():
+def test_alert_policy_path():
     project = "squid"
-    dashboard = "clam"
+    alert_policy = "clam"
+    expected = "projects/{project}/alertPolicies/{alert_policy}".format(
+        project=project, alert_policy=alert_policy,
+    )
+    actual = DashboardsServiceClient.alert_policy_path(project, alert_policy)
+    assert expected == actual
+
+
+def test_parse_alert_policy_path():
+    expected = {
+        "project": "whelk",
+        "alert_policy": "octopus",
+    }
+    path = DashboardsServiceClient.alert_policy_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = DashboardsServiceClient.parse_alert_policy_path(path)
+    assert expected == actual
+
+
+def test_dashboard_path():
+    project = "oyster"
+    dashboard = "nudibranch"
     expected = "projects/{project}/dashboards/{dashboard}".format(
         project=project, dashboard=dashboard,
     )
@@ -1939,8 +1886,8 @@ def test_dashboard_path():
 
 def test_parse_dashboard_path():
     expected = {
-        "project": "whelk",
-        "dashboard": "octopus",
+        "project": "cuttlefish",
+        "dashboard": "mussel",
     }
     path = DashboardsServiceClient.dashboard_path(**expected)
 
@@ -1950,7 +1897,7 @@ def test_parse_dashboard_path():
 
 
 def test_common_billing_account_path():
-    billing_account = "oyster"
+    billing_account = "winkle"
     expected = "billingAccounts/{billing_account}".format(
         billing_account=billing_account,
     )
@@ -1960,7 +1907,7 @@ def test_common_billing_account_path():
 
 def test_parse_common_billing_account_path():
     expected = {
-        "billing_account": "nudibranch",
+        "billing_account": "nautilus",
     }
     path = DashboardsServiceClient.common_billing_account_path(**expected)
 
@@ -1970,7 +1917,7 @@ def test_parse_common_billing_account_path():
 
 
 def test_common_folder_path():
-    folder = "cuttlefish"
+    folder = "scallop"
     expected = "folders/{folder}".format(folder=folder,)
     actual = DashboardsServiceClient.common_folder_path(folder)
     assert expected == actual
@@ -1978,7 +1925,7 @@ def test_common_folder_path():
 
 def test_parse_common_folder_path():
     expected = {
-        "folder": "mussel",
+        "folder": "abalone",
     }
     path = DashboardsServiceClient.common_folder_path(**expected)
 
@@ -1988,7 +1935,7 @@ def test_parse_common_folder_path():
 
 
 def test_common_organization_path():
-    organization = "winkle"
+    organization = "squid"
     expected = "organizations/{organization}".format(organization=organization,)
     actual = DashboardsServiceClient.common_organization_path(organization)
     assert expected == actual
@@ -1996,7 +1943,7 @@ def test_common_organization_path():
 
 def test_parse_common_organization_path():
     expected = {
-        "organization": "nautilus",
+        "organization": "clam",
     }
     path = DashboardsServiceClient.common_organization_path(**expected)
 
@@ -2006,7 +1953,7 @@ def test_parse_common_organization_path():
 
 
 def test_common_project_path():
-    project = "scallop"
+    project = "whelk"
     expected = "projects/{project}".format(project=project,)
     actual = DashboardsServiceClient.common_project_path(project)
     assert expected == actual
@@ -2014,7 +1961,7 @@ def test_common_project_path():
 
 def test_parse_common_project_path():
     expected = {
-        "project": "abalone",
+        "project": "octopus",
     }
     path = DashboardsServiceClient.common_project_path(**expected)
 
@@ -2024,8 +1971,8 @@ def test_parse_common_project_path():
 
 
 def test_common_location_path():
-    project = "squid"
-    location = "clam"
+    project = "oyster"
+    location = "nudibranch"
     expected = "projects/{project}/locations/{location}".format(
         project=project, location=location,
     )
@@ -2035,8 +1982,8 @@ def test_common_location_path():
 
 def test_parse_common_location_path():
     expected = {
-        "project": "whelk",
-        "location": "octopus",
+        "project": "cuttlefish",
+        "location": "mussel",
     }
     path = DashboardsServiceClient.common_location_path(**expected)
 
